## nobug
[![PyPI version](https://img.shields.io/pypi/v/nobug.svg)](https://pypi.python.org/pypi/nobug/)

## introduction

没有bug
没有bug
没有bug

佛祖、Jesus、神兽保佑代码无bug


## install
```
$ pip3 install nobug
```

## usage

选一个吧
```
from nobug import success
from nobug import Jesus
from nobug import caonima
from nobug import awesome_caonima
from nobug import book
from nobug import success
# write your own code
```

## screenshot
![](http://oqyjccf1n.bkt.clouddn.com/20180403-103502.png)

## refer
- [nobug](https://gist.github.com/edokeh/7580064)
